@@ -373,7 +373,6 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     time_t event_end_time = (*event_iter)->getDateEnd();
     time_t event_time_offset = (*event_iter)->getTzOffset();
 
-
     if(CMulticalendar::MCInstance()->getSystemTimeShift() != (*event_iter)->getTzOffset() &&
        ((*event_iter)->getAllDay() ||
 	(*event_iter)->getType() == E_TODO))
@@ -382,7 +381,7 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       event_start_time += event_time_offset - system_time_offset;
     }
 
-    struct tm* time = localtime(&event_start_time);
+
 
     if(event_end_time > date_today_time && earliest_update_end_time>event_end_time)
     {
@@ -394,6 +393,8 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       earliest_update_end_time = event_start_time+60;
     }
     char buf[255];
+    struct tm* time = localtime(&event_start_time);
+
     if((*event_iter)->getType() == E_TODO)
     {
       _format_todo_time(*event_iter, buf, desktop_plugin);
@@ -430,7 +431,8 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
 	g_free(tt);
       }
       else
-	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_short"), time);
+	//	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_short"), time);
+	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date"), time);
       gtk_list_store_set(list_store, &iter,
 			 0, buf,
 			 -1);
@@ -477,12 +479,12 @@ calendar_getComponents(int calendarId,
   error = CALENDAR_OPERATION_SUCCESSFUL;
   
   CCalendarDB *pDb = CCalendarDB::Instance();
-  time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
 
   int iNewStDate = 0;
   int iNewEndDate = 0;
   CMulticalendar *mc = CMulticalendar::MCInstance();
-  int time_diff = time_get_time_diff (iStDate, mc->getSystemTimeZone().c_str(), "UTC");
+  int time_diff = time_get_time_diff(iStDate, mc->getSystemTimeZone().c_str(), "UTC");
+
   iNewStDate = iStDate + time_diff;
   iNewEndDate = iEndDate + time_diff;
 
@@ -673,9 +675,7 @@ cal_read_todos_for_calendar(CCalendar* calendar,
     for(int k=0;k<calendars_components.size();++k)
     {
       CComponent* component = calendars_components[k];
-      gchar buf[256];
       time_t event_time = component->getDateStart();
-      struct tm* time = localtime(&event_time);
       if(_todo_is_old(component, &today_midnight))
       {
 	if((component->getStatus() == 0) &&
@@ -713,8 +713,6 @@ cal_read_ccomponents_for_calendar(CCalendar* calendar,
   int offset = 0;
   int size = 0;
   int limit = 500;
-  time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
-  string system_time_zone = CMulticalendar::MCInstance()->getSystemTimeZone();
   do
   {
     int event_type = E_EVENT;
@@ -767,7 +765,7 @@ cal_read_ccomponents_for_calendar(CCalendar* calendar,
 	    // and set end time 
 	    CComponent* c = new CComponent(*component);
 	    c->setDateEnd((*iter) + c->getDateEnd() - c->getDateStart());
-	    c->setDateStart(*iter);
+	    c->setDateStart((*iter) + c->getTzOffset());
 
 	    if(c->getType() == E_BDAY &&
 	       desktop_plugin->show_age)
