@@ -91,9 +91,9 @@ show_visible_calendars_dlg(GtkButton* button, gpointer data)
 				     TRUE);
       }
     }
-
+    const gchar* calendar_name = dgettext("calendar", (*calendars_iter)->getCalendarName().c_str());
     gtk_button_set_label(GTK_BUTTON(check_button),
-			 (*calendars_iter)->getCalendarName().c_str());
+			 calendar_name);
 
     GtkWidget* image = create_calendar_colour_icon_image((*calendars_iter)->getCalendarColor(),
 							 HILDON_ICON_SIZE_FINGER);
